
#ifndef _C15_ds700_
#define _C15_ds700_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_NATURAL_32 F1015_6842(EIF_REFERENCE);
extern void EIF_Minit700(void);
extern EIF_NATURAL_32 F1100_7547(EIF_REFERENCE, EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
